# -*- coding: utf-8 -*-

from .acfun import AcFun

__author__ = "Aruelius"
__email__ = "aurelius@aliyun.com"
__version__ = "0.0.3"
